Following brms semantics loosely: the fixed coefficients plus, per grouping structure, the unit-level effects (fixed part + random deviation).
Usage
# S3 method for class 'bml'
coef(object, ...)Following brms semantics loosely: the fixed coefficients plus, per grouping structure, the unit-level effects (fixed part + random deviation).
# S3 method for class 'bml'
coef(object, ...)