Skip to contents

PSIS-LOO via the loo package, computed from the monitored pointwise log-likelihood. Available for gaussian and bernoulli families fitted with monitor = TRUE. Compare models with loo::loo_compare().

Usage

# S3 method for class 'bml'
loo(x, ...)

Arguments

x

A fitted bml model.

...

Passed to loo::loo.matrix().

Value

A loo object.