The bml analogues of brms::make_stancode() / make_standata():
build the model exactly as bml would, but return the generated
JAGS model string (make_jagscode) or the JAGS data list
(make_jagsdata) instead of fitting.
The bml analogues of brms::make_stancode() / make_standata():
build the model exactly as bml would, but return the generated
JAGS model string (make_jagscode) or the JAGS data list
(make_jagsdata) instead of fitting.